Repository Api
=================


.. currentmodule:: anyvc.repository

.. autofunction:: open

.. autofunction:: find


.. currentmodule:: anyvc.common.repository

.. autoclass:: Repository
  :members:

.. autoclass:: Revision
  :members:

  .. attribute:: id

    The revision id the vcs gave this commit

    :type: int or string

